@@ -11,11 +11,11 @@ fn main() {
     let out_path = PathBuf::from(env::var("OUT_DIR").unwrap());
     let lib_dir = out_path.join("library");
 
-    // Compile tsf_src.h into a library at ${OUT_DIR}/library
+    // Compile tsf_src.h into a library at ${OUT_DIR}/library/libtsf.a
     cc::Build::new()
         .include("tsf_src")
+        .pic(true)
         .file("tsf_src/tsf.c")
-        // .define("TSF_IMPLEMENTATION", None)
         .out_dir(&lib_dir)
         .compile("libtsf.a");
 
@@ -24,18 +24,19 @@ fn main() {
     println!("cargo:rustc-link-lib=static=tsf", );
 
     // Generate the bindings
-    bindgen::Builder::default()
+    let bindings = bindgen::Builder::default()
         // The input header we would like to generate
         // bindings for.
         .header("wrapper.h")
+        .detect_include_paths(true)
         // Tell cargo to invalidate the built crate whenever any of the
         // included header files changed.
         .parse_callbacks(Box::new(bindgen::CargoCallbacks))
         // Finish the builder and generate the bindings.
         .generate()
         // Unwrap the Result and panic on failure.
-        .expect("Unable to generate bindings")
+        .expect("Unable to generate bindings");
+
         // Write to our out dir
-        .write_to_file(out_path.join("bindings.rs"))
-        .expect("Couldn't write bindings");
-}
\ No newline at end of file
+        bindings.write_to_file(out_path.join("bindings.rs")).expect("Couldn't write bindings");
+}
